==> enterprisemodules-ora_config-3.18.3.tar.gz: enterprisemodules-ora_config-3.18.3/lib/puppet/type/ora_autotask.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'

# @nodoc
module Puppet
  Type.newtype(:ora_autotask) do
    include EasyType
    include Puppet_X::EnterpriseModules::Oracle::Access

    desc <<-EOD
      This resource allows you to manage auto tasks in the (pluggable) database

      It allows you to enable/disable individual tasks (sql_tuning_advisor, auto_optimizer_stats_collection, auto_space_advisor)
      or enable/disable all the auto tasks (auto_task)

      ora_autotask { 'DBNAME':
        auto_optimizer_stats_collection => 'enabled',
        auto_space_advisor              => 'enabled',
        auto_task                       => 'enabled',
        sql_tuning_advisor              => 'enabled',
      }
    EOD

    to_get_raw_resources do
      sql_on_all_primary_database_sids %Q(
        col client form a40
        col name form a10
        col sql_tuning_advisor form a20
        col auto_optimizer_stats_collect form a32
        col auto_space_advisor form a20
        col auto_task form a10
        select *
          from (
            select 'state' as state
                 , sys_context('USERENV','DB_NAME') as name
                 , client_name
                 , status
              from dba_autotask_client
            union
            select 'state' as state
                 , sys_context('USERENV','DB_NAME') as name
                 , 'auto task' as client_name
                 , status
              from dba_autotask_status
            )
            pivot
            (
              max(lower(status)) for client_name in ('auto task' auto_task, 'sql tuning advisor' sql_tuning_advisor, 'auto optimizer stats collection' auto_optimizer_stats_collect, 'auto space advisor' auto_space_advisor)
            )
      )
    end

    on_modify do
      # handled in individual properties
      nil
    end

    parameter :name
    property :auto_optimizer_stats_collection
    property :auto_space_advisor
    property :auto_task
    property :sql_tuning_advisor

  end
end

==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/type/ora_autotask.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'

# @nodoc
module Puppet
  Type.newtype(:ora_autotask) do
    include EasyType
    include Puppet_X::EnterpriseModules::Oracle::Access

    desc <<-DESC
      This resource allows you to manage auto tasks in the (pluggable) database

      It allows you to enable/disable individual tasks (sql_tuning_advisor, auto_optimizer_stats_collection, auto_space_advisor)
      or enable/disable all the auto tasks (auto_task)

      ora_autotask { 'DBNAME':
        auto_optimizer_stats_collection => 'enabled',
        auto_space_advisor              => 'enabled',
        auto_task                       => 'enabled',
        sql_tuning_advisor              => 'enabled',
      }
    DESC

    to_get_raw_resources do
      sql_on_all_primary_database_sids %(
        col client form a40
        col name form a10
        col sql_tuning_advisor form a20
        col auto_optimizer_stats_collect form a32
        col auto_space_advisor form a20
        col auto_task form a10
        select *
          from (
            select 'state' as state
                 , sys_context('USERENV','DB_NAME') as name
                 , client_name
                 , status
              from dba_autotask_client
            union
            select 'state' as state
                 , sys_context('USERENV','DB_NAME') as name
                 , 'auto task' as client_name
                 , status
              from dba_autotask_status
            )
            pivot
            (
              max(lower(status)) for client_name in ('auto task' auto_task, 'sql tuning advisor' sql_tuning_advisor, 'auto optimizer stats collection' auto_optimizer_stats_collect, 'auto space advisor' auto_space_advisor)
            )
      )
    end

    on_modify do
      # handled in individual properties
      nil
    end

    parameter :name
    property :auto_optimizer_stats_collection
    property :auto_space_advisor
    property :auto_task
    property :sql_tuning_advisor
  end
end
